# PySolarCell

A detailed balance solar cell solver for multijunction tandem solar cells. It supports IV and EQE calculation, and different connection types between layers e.g. series, parallel and mixed.

## Installation

Ensure that Python 3 and pip are installed and added to your environment PATH.

```python -m pip install pysolarcell```

Open a Python console and run the following command.

```import pysolarcell```

If you receive no errors, the installation was successful.